@@ -1,5 +1,5 @@
 /* AppletViewer.java -- a standalone viewer for Java applets
-   Copyright (C) 2003, 2004  Thomas Fitzsimmons <fitzsim@redhat.com>
+   Copyright (C) 2003, 2004, 2006  Thomas Fitzsimmons <fitzsim@redhat.com>
 
    This file is part of GCJ Applet Viewer.
 
@@ -52,50 +52,38 @@ class AppletViewer
   
   private static ClassLoader getClassLoader(URL codebase, ArrayList archives)
   {
-    // Ask cache for existing class loader.
-    AppletClassLoader loader = (AppletClassLoader) classLoaderCache.get(codebase);
+    // Should load class loader each time. It is possible that there
+    // are more than one applet to be loaded with different archives.
+    AppletClassLoader loader = new AppletClassLoader(codebase, archives);
+    classLoaderCache.put(codebase, loader);
 
-    if (loader == null)
-      {
-	// FIXME: why does URLClassLoader throw a NoClassDefFoundError
-	// when the html file we pass it is in the current working
-	// directory?  (e.g. the Slime Volleyball applet).  I suspect
-	// a URLClassLoader bug in libgcj.
-
-	// XXX: Add archives only the first time we see a codebase ...
-	loader = new AppletClassLoader(codebase, archives);
-
-	// Add new class loader to cache.
-	classLoaderCache.put(codebase, loader);
-      }
-    
     return loader;
   }
-
+  
   static Applet createApplet(AppletTag tag)
   {
     Applet applet = null;
 
     try
       {
-        ClassLoader loader = getClassLoader(tag.prependCodebase (""),
-						  tag.archives);
-	String code = tag.code;
+        ClassLoader loader = getClassLoader(tag.prependCodeBase(""),
+                                            tag.getArchives());
+        String code = tag.getCode();
 
-	if (code.endsWith(".class"))
-	  code = code.substring(0, code.length() - 6).replace('/', '.');
+        if (code.endsWith(".class"))
+          code = code.substring(0, code.length() - 6).replace('/', '.');
 
-	Class c = loader.loadClass(code);
-	applet = (Applet) c.newInstance();
+        Class c = loader.loadClass(code);
+        applet = (Applet) c.newInstance();
       }
     catch (Exception e)
       {
-	e.printStackTrace();
+        e.printStackTrace();
       }
 
     if (applet == null)
       applet = new ErrorApplet("Error loading applet");
-    
+
     return applet;
   }
 
@@ -122,6 +110,8 @@ class AppletViewer
     System.exit(status);
   }
 
+  protected static boolean verbose;
+
   /**
    * The main method starting the applet viewer.
    *
@@ -131,8 +121,6 @@ class AppletViewer
    */
   public static void main(String[] args) throws IOException
   {
-    String encoding = "UTF8";
-
     if (args.length == 0)
       {
 	System.err.println(AppletViewer.messages.getString
@@ -167,7 +155,6 @@ class AppletViewer
 
 	    // Remove the -encoding option.
 	    argsIter.remove();
-	    encoding = (String) argsIter.next();
 	    // Remove the argument to -encoding.
 	    argsIter.remove();
 	  }
@@ -187,6 +174,7 @@ class AppletViewer
         new LongOpt("plugin", LongOpt.REQUIRED_ARGUMENT, null, 0),
         new LongOpt("version", LongOpt.NO_ARGUMENT, null, 0),
         new LongOpt("help", LongOpt.NO_ARGUMENT, null, 0),
+        new LongOpt("verbose", LongOpt.NO_ARGUMENT, null, 0),
       };
 
     Getopt opts = new Getopt("gcjappletviewer", args, "", longOptions);
@@ -202,9 +190,6 @@ class AppletViewer
     String pipeInName = "";
     String pipeOutName = "";
 
-    boolean codeGiven = false;
-    boolean widthGiven = false;
-    boolean heightGiven = false;
     boolean pluginMode = false;
 
     // This loop parses the command line, placing all option arguments
@@ -216,30 +201,28 @@ class AppletViewer
 	  {
 	    optionIndex = opts.getLongind();
 
-	    if (optionIndex == 0) // --code
-	      {
-		codeGiven = true;
-		code = opts.getOptarg();
-	      }
-	    if (optionIndex == 1) // --codebase
+            // --code
+	    if (optionIndex == 0)
+              code = opts.getOptarg();
+            // --codebase
+	    if (optionIndex == 1)
 	      codebase = opts.getOptarg();
-	    if (optionIndex == 2) // --archive
+            // --archive
+            if (optionIndex == 2)
 	      archives = opts.getOptarg();
-	    else if (optionIndex == 3) // --param
+            // --param
+	    else if (optionIndex == 3)
 	      parameters.add(opts.getOptarg());
-	    else if (optionIndex == 4) // --width
-	      {
-		widthGiven = true;
-		dimensions.width =
-		  Math.max(1, Integer.parseInt(opts.getOptarg()));
-	      }
-	    else if (optionIndex == 5) // --height
-	      {
-		heightGiven = true;
-		dimensions.height =
-		  Math.max(1, Integer.parseInt(opts.getOptarg()));
-	      }
-	    else if (optionIndex == 6) // --plugin
+            // --width
+	    else if (optionIndex == 4)
+              dimensions.width =
+                Math.max(1, Integer.parseInt(opts.getOptarg()));
+            // --height
+	    else if (optionIndex == 5)
+              dimensions.height =
+                Math.max(1, Integer.parseInt(opts.getOptarg()));
+            // --plugin
+	    else if (optionIndex == 6)
 	      {
 		pluginMode = true;
 		String tmp = opts.getOptarg();
@@ -248,10 +231,17 @@ class AppletViewer
 		pipeOutName = tmp.substring(pos + 1);
 		break;
 	      }
-	    else if (optionIndex == 7) // --version
+            // --version
+	    else if (optionIndex == 7)
 	      printVersion();
-	    else if (optionIndex == 8) // --help
+            // --help
+	    else if (optionIndex == 8)
 	      printHelpMessage(0);
+            // --verbose
+            else if (optionIndex == 9)
+              {
+                verbose = true;
+              }
 	  }
       }
 
@@ -262,28 +252,53 @@ class AppletViewer
       dimensions.width = (int) (1.6 * dimensions.height);
 
     //System.setSecurityManager(new AppletSecurityManager(pluginMode));
-    
+
+    // Print arguments.
+    printArguments(args);
+
     if (pluginMode)
       {
 	InputStream in;
 	OutputStream out;
 
-	if (pipeInName.equals("stdin"))
-	  in = System.in;
-	else
-	  in = new FileInputStream(pipeInName);
-
-	if (pipeOutName.equals("stdout"))
-	  out = System.out;
-	else
-	  out = new FileOutputStream(pipeOutName);
+        in = new FileInputStream(pipeInName);
+        out = new FileOutputStream(pipeOutName);
 
 	PluginAppletViewer.start(in, out);
       }
     else
-      new StandaloneAppletViewer(code, codebase, archives, parameters,
-                                 dimensions, widthGiven, heightGiven,
-                                 codeGiven, args, opts, opts.getOptind(),
-                                 encoding);
+      {
+        if (code.equals(""))
+          {
+            // The --code option wasn't given and there are no URL
+            // arguments so we have nothing to work with.
+            if (opts.getOptind() == args.length)
+              {
+                System.err.println(AppletViewer.messages.getString("gcjappletviewer.no_input_files"));
+                printHelpMessage(1);
+              }
+            // Create a standalone appletviewer from a list of URLs.
+            String[] urls = new String[args.length - opts.getOptind()];
+            System.arraycopy(args, opts.getOptind(), urls, 0, args.length - opts.getOptind());
+            new StandaloneAppletViewer(urls);
+          }
+        else
+          {
+            // Create a standalone appletviewer from the --code
+            // option.
+            new StandaloneAppletViewer(code, codebase, archives, parameters, dimensions);
+          }
+      }
+  }
+
+  static void printArguments(String[] args)
+  {
+    if (verbose)
+      {
+        System.out.println("raw arguments:");
+
+        for (int i = 0; i < args.length; i++)
+          System.out.println(" " + args[i]);
+      }
   }
 }
