@@ -1,5 +1,5 @@
 /* gcjwebplugin - Webbrowser plugin to execute Java (tm) applets.
-   Copyright (C) 2003, 2004  Michael Koch <konqueror@gmx.de>
+   Copyright (C) 2003, 2004, 2006  Michael Koch <konqueror@gmx.de>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -35,33 +35,30 @@ exception statement from your version. */
 
 package gnu.gcjwebplugin;
 
-import java.awt.BorderLayout;
-import java.awt.Button;
-import java.awt.Frame;
-import java.awt.TextArea;
+import javax.swing.JOptionPane;
 
 
 /**
  * @author Michael Koch (konqueror@gmx.de)
  */
-public class AppletWarning extends Frame
+public class AppletWarning
 {
-  /**
-   * Contructs a frame showing a security warning.
-   */
-  public AppletWarning()
+  private static String TITLE = "WARNING";
+
+  private static String MESSAGE =
+    "The current version of this applet plugin does not provide\n" +
+    "a security manager capable of handling Java (tm) applets. Applets\n" +
+    "have UNRESTRICTED access to your computer. This means they can do\n" +
+    "anything you can do, like deleting all your important data.\n\n" +
+    "Continue ?";
+  
+  public static int show()
   {
-    setLayout(new BorderLayout());
+    if (! UserConfiguration.showWarning())
+      return JOptionPane.YES_OPTION;
 
-    TextArea text =
-      new TextArea("WARNING: The current version of this applet plugin does not provide "
-                   + "a security manager capable of handling Java (tm) applets. Applets "
-                   + "have UNRESTRICTED access to your computer. This means they can do "
-                   + "anything you can do, like deleting all your important data.",
-                   20, 5, TextArea.SCROLLBARS_NONE);
-    text.setEditable(false);
-    add(text, BorderLayout.CENTER);
-
-    add(new Button("Continue"), BorderLayout.SOUTH);
+    return JOptionPane.showConfirmDialog(null, MESSAGE, TITLE,
+                                         JOptionPane.YES_NO_OPTION,
+                                         JOptionPane.WARNING_MESSAGE);
   }
 }
