@@ -1,5 +1,5 @@
 /* PluginAppletContext.java -- an applet's context within a web browser
-   Copyright (C) 2003  Thomas Fitzsimmons <fitzsim@redhat.com>
+   Copyright (C) 2003, 2006  Thomas Fitzsimmons <fitzsim@redhat.com>
 
    This file is part of GCJ Applet Viewer.
 
@@ -21,7 +21,7 @@
 package gnu.gcjwebplugin;
 
 import java.net.URL;
-
+import java.io.IOException;
 
 /*
  * PluginAppletContext represents the context within a webpage of a
@@ -29,15 +29,27 @@ import java.net.URL;
  */
 class PluginAppletContext extends CommonAppletContext
 {
-  // FIXME: implement.
   public void showDocument(URL url, String target)
   {
-    System.err.println("showDocument is not implemented in plugin mode");
+    try
+      {
+        PluginAppletViewer.write("url " + url + " " + target);
+      }
+    catch(IOException e)
+      {
+        System.err.println("showDocument failed: " + e);
+      }
   }
 
-  // FIXME: implement.
   public void showStatus(String status)
   {
-    System.err.println("showStatus is not implemented in plugin mode");
+    try
+      {
+        PluginAppletViewer.write("status " + status);
+      }
+    catch(IOException e)
+      {
+        System.err.println("showDocument failed: " + e);
+      }
   }
 }
