@@ -1,5 +1,5 @@
 /* PluginAppletViewer.java - manages embeddable applet windows
-   Copyright (C) 2003  Thomas Fitzsimmons <fitzsim@redhat.com>
+   Copyright (C) 2003, 2006  Thomas Fitzsimmons <fitzsim@redhat.com>
 
    This file is part of GCJ Applet Viewer.
 
@@ -27,8 +27,8 @@ import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.io.OutputStream;
 import java.io.OutputStreamWriter;
-import java.io.PrintStream;
 import java.net.MalformedURLException;
+import java.nio.charset.Charset;
 import java.util.HashMap;
 
 
@@ -42,31 +42,19 @@ class PluginAppletViewer
   // A mapping of instance IDs to PluginAppletWindows.
   static HashMap appletWindows = new HashMap ();
 
-  private static ConsoleDialog consoleDialog;
-  
   private static BufferedReader pluginInputStream;
   private static BufferedWriter pluginOutputStream;
-  private static PrintStream stdOut;
-  private static PrintStream stdErr;
-
-  static
-  {
-    // FIXME: Shouldn't we do lazy instantiation here ?
-    consoleDialog = new ConsoleDialog();
-
-    stdOut = System.out;
-    System.setOut(consoleDialog.getPrintStream());
-    stdErr = System.err;
-    System.setErr(consoleDialog.getPrintStream());
-  }
 
   static void start(InputStream inputStream, OutputStream outputStream)
     throws MalformedURLException, IOException
   {
-    // Set up input and output pipes.
-    pluginInputStream = new BufferedReader(new InputStreamReader(inputStream));
+    // Set up input and output pipes.  Use UTF-8 encoding.
+    pluginInputStream =
+      new BufferedReader(new InputStreamReader(inputStream,
+                                               Charset.forName("UTF-8")));
     pluginOutputStream =
-      new BufferedWriter(new OutputStreamWriter(outputStream));
+      new BufferedWriter(new OutputStreamWriter(outputStream,
+                                                Charset.forName("UTF-8")));
 
     write("running");
 
@@ -91,13 +79,12 @@ class PluginAppletViewer
 	  {
 	    int pos = message.indexOf(' ', 4);
 	    String documentbase = message.substring(4, pos);
-	    String tag = message.substring(pos + 1);
-
-	    currentWindow.setTag(tag, documentbase, "UTF8");
+        String tag = message.substring(pos + 1);
+        currentWindow.setParser(tag, documentbase);
 	  }
-	else if (message.startsWith("xid"))
+	else if (message.startsWith("handle"))
 	  {
-	    long handle = Long.parseLong(message.substring(4));
+	    long handle = Long.parseLong(message.substring(7));
 
 	    currentWindow.setHandle(handle);
 	  }
@@ -137,7 +124,7 @@ class PluginAppletViewer
     pluginOutputStream.newLine();
     pluginOutputStream.flush();
 
-    stdOut.println("  PIPE: applet viewer wrote: " + message);
+    System.err.println("  PIPE: applet viewer wrote: " + message);
   }
 
   /**
@@ -151,7 +138,7 @@ class PluginAppletViewer
   {
     String message = pluginInputStream.readLine();
 
-    stdOut.println("  PIPE: applet viewer read: " + message);
+    System.err.println("  PIPE: applet viewer read: " + message);
 
     if (message == null || message.equals("shutdown"))
       {
@@ -159,7 +146,7 @@ class PluginAppletViewer
 	pluginInputStream.close();
 	pluginOutputStream.close();
 
-	System.out.println("Exiting plugin applet viewer!");
+	System.err.println("gcjappletviewer: exiting plugin applet viewer");
 	System.exit(0);
       }
 
